BindingValue

Enum BindingValue 

pub enum BindingValue<T> {
    Value(T),
    SecretRef {
        secret_ref: SecretReference,
    },
    Expression(Value),
}
Represents a value that can be either a concrete value, a template expression, or a reference to a Kubernetes Secret

Variants



Value(T)

A concrete value (used by controllers)



SecretRef

A Kubernetes Secret reference (must come before Expression)

Fields

secret_ref: SecretReference


Expression(Value)

A template expression (used by IaC template generators)

Implementations

Source

impl<T> BindingValue<T>

pub fn value(val: T) -> Self

Creates a concrete value

pub fn expression(expr: JsonValue) -> Self

Creates a template expression

pub fn into_value(self, binding_name: &str, field_name: &str) -> Result<T>

Extracts the concrete value, returning an error if this is a template expression or SecretRef