RuntimeClientFrame

Enum RuntimeClientFrame 

pub enum RuntimeClientFrame {
    StartShell {
        cols: u16,
        rows: u16,
    },
    StartExec {
        command: Vec<String>,
        timeout_ms: Option<u64>,
    },
    Stdin {
        data_b64: String,
    },
    Resize {
        cols: u16,
        rows: u16,
    },
    CloseStdin,
    Cancel,
}
Client-to-agent runtime debug frames, relayed by the manager.

Variants



StartShell

Start an interactive shell with an optional initial terminal size.

Fields

cols: u16

Terminal columns.

rows: u16

Terminal rows.



StartExec

Start a non-interactive command.

Fields

command: Vec<String>

Executable and argv to run on the remote host.

timeout_ms: Option<u64>

Optional timeout in milliseconds.



Stdin

Standard input bytes, base64-encoded.

Fields

data_b64: String

Base64-encoded bytes.



Resize

Resize the interactive terminal.

Fields

cols: u16

Terminal columns.

rows: u16

Terminal rows.



CloseStdin

Close stdin for the remote process.



Cancel

Cancel the remote process.