pub enum AiAvailabilitySource {
AwsBedrock,
GcpVertex,
AzureFoundry,
Anthropic,
}Expand description
Provider control plane used to observe model availability without invoking a model, spending customer quota, or accepting provider terms.
Variants