pub enum BuildHost {
LinuxX64,
LinuxArm64,
WindowsX64,
DarwinArm64,
Unsupported,
}Expand description
Operating system and architecture of the machine running a build.
Variants
LinuxX64
Linux x86-64.
LinuxArm64
Linux ARM64.
WindowsX64
Windows x86-64.
DarwinArm64
macOS ARM64.
Unsupported
A host Alien does not support. This includes Darwin x64 and Windows ARM64, for which Alien does not publish native runtime targets.
Implementations