pub enum InitialSetupAuthority {
ImportedHandoff,
DirectSetup,
}Expand description
Actor that owns structural work during the initial setup phase.
Variants
ImportedHandoff
Setup state was registered by an external setup engine. Alien may only continue controller states that the importer explicitly initialized.
DirectSetup
Alien is the setup engine and is running with administrator credentials.