StackStatus

Enum StackStatus 

pub enum StackStatus {
    Pending,
    InProgress,
    Running,
    Deleted,
    Failure,
}
Represents the overall status of a stack based on its resource states.

Variants



Pending

Stack is initializing with no resources yet created



InProgress

Stack has resources that are currently being provisioned, updated, or deleted



Running

All resources are successfully running and the stack is operational



Deleted

All resources have been successfully deleted and the stack is removed



Failure

One or more resources have failed during provisioning, updating, or deleting