pub enum AlienEvent {
Show 31 variants
LoadingConfiguration,
Finished,
BuildingStack {
stack: String,
},
RunningPreflights {
stack: String,
platform: String,
},
DownloadingAlienRuntime {
target_triple: String,
url: String,
},
BuildingResource {
resource_name: String,
resource_type: String,
related_resources: Vec<String>,
},
BuildingImage {
image: String,
},
PushingImage {
image: String,
progress: Option<PushProgress>,
},
PushingStack {
stack: String,
platform: String,
},
PushingResource {
resource_name: String,
resource_type: String,
},
CreatingRelease {
project: String,
},
CompilingCode {
language: String,
progress: Option<String>,
},
StackStep {
next_state: StackState,
suggested_delay_ms: Option<u64>,
},
GeneratingCloudFormationTemplate,
GeneratingTemplate {
platform: String,
},
ProvisioningAgent {
agent_id: String,
release_id: String,
},
UpdatingAgent {
agent_id: String,
release_id: String,
},
DeletingAgent {
agent_id: String,
release_id: String,
},
DebuggingAgent {
agent_id: String,
debug_session_id: String,
},
PreparingEnvironment {
strategy_name: String,
},
DeployingStack {
stack_name: String,
},
RunningTestFunction {
stack_name: String,
},
CleaningUpStack {
stack_name: String,
strategy_name: String,
},
CleaningUpEnvironment {
stack_name: String,
strategy_name: String,
},
SettingUpPlatformContext {
platform_name: String,
},
EnsuringDockerRepository {
repository_name: String,
},
DeployingCloudFormationStack {
cfn_stack_name: String,
current_status: String,
},
AssumingRole {
role_arn: String,
},
ImportingStackStateFromCloudFormation {
cfn_stack_name: String,
},
DeletingCloudFormationStack {
cfn_stack_name: String,
current_status: String,
},
EmptyingBuckets {
bucket_names: Vec<String>,
},
}Expand description
Represents all possible events in the Alien system
Variants
LoadingConfiguration
Loading configuration file
Finished
Operation finished successfully
BuildingStack
Stack packaging event
RunningPreflights
Running build-time preflight checks and mutations
DownloadingAlienRuntime
Downloading alien runtime event
BuildingResource
Resource build event (function, container, or worker)
Fields
All resource names sharing this build (for deduped container groups)
BuildingImage
Image build event
PushingImage
Image push event
Fields
progress: Option<PushProgress>Progress information for the push operation
PushingStack
Pushing stack images to registry
PushingResource
Pushing resource images to registry
Fields
CreatingRelease
Creating a release on the platform
CompilingCode
Code compilation event (rust, typescript, etc.)
Fields
StackStep
Fields
next_state: StackStateThe resulting state of the stack after the step.
GeneratingCloudFormationTemplate
Generating CloudFormation template
GeneratingTemplate
Generating infrastructure template
ProvisioningAgent
Provisioning a new agent
Fields
UpdatingAgent
Updating an existing agent
Fields
DeletingAgent
Deleting an agent
Fields
DebuggingAgent
Starting a debug session for an agent
Fields
PreparingEnvironment
Preparing environment for deployment
DeployingStack
Deploying stack with alien-infra
RunningTestFunction
Running test function after deployment
CleaningUpStack
Cleaning up deployed stack resources
Fields
CleaningUpEnvironment
Cleaning up deployment environment
Fields
SettingUpPlatformContext
Setting up platform context
EnsuringDockerRepository
Ensuring docker repository exists
DeployingCloudFormationStack
Deploying CloudFormation stack
Fields
AssumingRole
Assuming AWS IAM role
ImportingStackStateFromCloudFormation
Importing stack state from CloudFormation
DeletingCloudFormationStack
Deleting CloudFormation stack
Fields
EmptyingBuckets
Emptying S3 buckets before stack deletion
Implementations
Sourceimpl AlienEvent
impl AlienEvent
Sourcepub async fn emit(self) -> Result<EventHandle>
pub async fn emit(self) -> Result<EventHandle>
Emit this event and wait for it to be handled
Sourcepub async fn emit_with_state(self, state: EventState) -> Result<EventHandle>
pub async fn emit_with_state(self, state: EventState) -> Result<EventHandle>
Emit this event with a specific initial state
Sourcepub async fn emit_with_parent(self, parent_id: &str) -> Result<EventHandle>
pub async fn emit_with_parent(self, parent_id: &str) -> Result<EventHandle>
Emit this event as a child of another event
Sourcepub async fn in_scope<F, Fut, T, E>(self, f: F) -> Result<T, AlienError<E>>where
F: FnOnce(EventHandle) -> Fut,
Fut: Future<Output = Result<T, AlienError<E>>>,
E: AlienErrorData + Clone + Debug + Serialize + Send + Sync + 'static,
pub async fn in_scope<F, Fut, T, E>(self, f: F) -> Result<T, AlienError<E>>where
F: FnOnce(EventHandle) -> Fut,
Fut: Future<Output = Result<T, AlienError<E>>>,
E: AlienErrorData + Clone + Debug + Serialize + Send + Sync + 'static,
Start a scoped event that will track success/failure All events emitted within the scope will automatically be children of this event