azure_disk_image_label

Function azure_disk_image_label 

pub fn azure_disk_image_label(reference: &str) -> String
The label value naming the disk image built from reference: a digest, since a label value may not carry a reference’s /, : and @.