pub fn kubernetes_compute_node_selector(
stack: &Stack,
pool: Option<&CapacityGroup>,
) -> Result<Option<BTreeMap<String, String>>, String>Expand description
Match Pod placement to the architecture used by the stack’s source images. This does not associate Workers with a compute pool or reserve node capacity.