pub fn remote_binding_is_deliverable(entry: &ResourceEntry) -> boolExpand description
Whether a declaration’s remote binding is one a deployment can actually deliver.
pub fn remote_binding_is_deliverable(entry: &ResourceEntry) -> boolWhether a declaration’s remote binding is one a deployment can actually deliver.