SandboxBuildRoleBuilder

Struct SandboxBuildRoleBuilder 

pub struct SandboxBuildRoleBuilder<'a, S: State = Empty> { /* private fields */ }
Use builder syntax to set the inputs and finish with build().

Implementations

Source

impl<'a, S: State> SandboxBuildRoleBuilder<'a, S>

pub fn build(self) -> SandboxBuildRole<'a>
where S: IsComplete,

Finish building and return the requested object

pub fn sandbox_id( self, value: &'a str, ) -> SandboxBuildRoleBuilder<'a, SetSandboxId<S>>
where S::SandboxId: IsUnset,

Required.

pub fn partition( self, value: &'a str, ) -> SandboxBuildRoleBuilder<'a, SetPartition<S>>
where S::Partition: IsUnset,

Required.

pub fn account_id( self, value: &'a str, ) -> SandboxBuildRoleBuilder<'a, SetAccountId<S>>
where S::AccountId: IsUnset,

Required.

pub fn region(self, value: &'a str) -> SandboxBuildRoleBuilder<'a, SetRegion<S>>
where S::Region: IsUnset,

Required.

pub fn bundle_uri( self, value: &'a str, ) -> SandboxBuildRoleBuilder<'a, SetBundleUri<S>>
where S::BundleUri: IsUnset,

Required.

The sandbox’s code.image as declared; a {region} token resolves to region.

pub fn runtime_built( self, value: bool, ) -> SandboxBuildRoleBuilder<'a, SetRuntimeBuilt<S>>
where S::RuntimeBuilt: IsUnset,

Required.

A Live sandbox, whose image the runtime rebuilds from each new bundle.

pub fn private_base_image( self, value: &'a str, ) -> SandboxBuildRoleBuilder<'a, SetPrivateBaseImage<S>>
where S::PrivateBaseImage: IsUnset,

Optional (Some / Option setters). The sandbox’s privateBaseImage; a {region} token in its host resolves to region.

pub fn maybe_private_base_image( self, value: Option<&'a str>, ) -> SandboxBuildRoleBuilder<'a, SetPrivateBaseImage<S>>
where S::PrivateBaseImage: IsUnset,

Optional (Some / Option setters). The sandbox’s privateBaseImage; a {region} token in its host resolves to region.