ArtifactRegistryBuilder

Struct ArtifactRegistryBuilder 

pub struct ArtifactRegistryBuilder<S: State = Empty> { /* private fields */ }
Use builder syntax to set the inputs and finish with build().

Implementations

Source

impl<S: State> ArtifactRegistryBuilder<S>

pub fn build(self) -> ArtifactRegistry
where S: IsComplete,

Finish building and return the requested object

pub fn replication_regions( self, value: Vec<String>, ) -> ArtifactRegistryBuilder<SetReplicationRegions<S>>
where S::ReplicationRegions: IsUnset,

Optional (Some / Option setters). Default: <Vec<String> as Default>::default().

AWS-only: regions to replicate container images to. ECR private image replication ensures images pushed in the registry’s home region are automatically available in these additional regions (required when Lambda or other compute runs in a different region from the registry).

pub fn maybe_replication_regions( self, value: Option<Vec<String>>, ) -> ArtifactRegistryBuilder<SetReplicationRegions<S>>
where S::ReplicationRegions: IsUnset,

Optional (Some / Option setters). Default: <Vec<String> as Default>::default().

AWS-only: regions to replicate container images to. ECR private image replication ensures images pushed in the registry’s home region are automatically available in these additional regions (required when Lambda or other compute runs in a different region from the registry).