pub struct AzureResourceGroup {
pub id: String,
}Expand description
Represents an Azure Resource Group that acts as a logical container for Azure resources.
Fields
id: StringIdentifier for the resource group. Must contain only alphanumeric characters, hyphens, and underscores ([A-Za-z0-9-_]). Maximum 64 characters.
Implementations
Sourceimpl AzureResourceGroup
impl AzureResourceGroup
Sourcepub fn new(id: String) -> AzureResourceGroupBuilder
pub fn new(id: String) -> AzureResourceGroupBuilder
Create an instance of AzureResourceGroup using the builder syntax
Sourceimpl AzureResourceGroup
impl AzureResourceGroup
Sourcepub const RESOURCE_TYPE: ResourceType
pub const RESOURCE_TYPE: ResourceType
The resource type identifier for Azure Resource Groups