pub struct BuildBuilder<S: State = Empty> { /* private fields */ }Expand description
Use builder syntax to set the inputs and finish with build().
Implementations
Sourceimpl<S: State> BuildBuilder<S>
impl<S: State> BuildBuilder<S>
Sourcepub fn build(self) -> Buildwhere
S: IsComplete,
pub fn build(self) -> Buildwhere
S: IsComplete,
Finish building and return the requested object
Sourcepub fn permissions(self, value: String) -> BuildBuilder<SetPermissions<S>>where
S::Permissions: IsUnset,
pub fn permissions(self, value: String) -> BuildBuilder<SetPermissions<S>>where
S::Permissions: IsUnset,
Required.
Permission profile name that defines the permissions granted to this build. This references a profile defined in the stack’s permission definitions.
Sourcepub fn environment(
self,
value: HashMap<String, String>,
) -> BuildBuilder<SetEnvironment<S>>where
S::Environment: IsUnset,
pub fn environment(
self,
value: HashMap<String, String>,
) -> BuildBuilder<SetEnvironment<S>>where
S::Environment: IsUnset,
Sourcepub fn maybe_environment(
self,
value: Option<HashMap<String, String>>,
) -> BuildBuilder<SetEnvironment<S>>where
S::Environment: IsUnset,
pub fn maybe_environment(
self,
value: Option<HashMap<String, String>>,
) -> BuildBuilder<SetEnvironment<S>>where
S::Environment: IsUnset,
Sourcepub fn compute_type(self, value: ComputeType) -> BuildBuilder<SetComputeType<S>>where
S::ComputeType: IsUnset,
pub fn compute_type(self, value: ComputeType) -> BuildBuilder<SetComputeType<S>>where
S::ComputeType: IsUnset,
Sourcepub fn maybe_compute_type(
self,
value: Option<ComputeType>,
) -> BuildBuilder<SetComputeType<S>>where
S::ComputeType: IsUnset,
pub fn maybe_compute_type(
self,
value: Option<ComputeType>,
) -> BuildBuilder<SetComputeType<S>>where
S::ComputeType: IsUnset,
Sourceimpl<S: State> BuildBuilder<S>
impl<S: State> BuildBuilder<S>