DaemonBuilder

Struct DaemonBuilder 

pub struct DaemonBuilder<S: State = Empty> { /* private fields */ }
Use builder syntax to set the inputs and finish with build().

Implementations

Source

impl<S: State> DaemonBuilder<S>

pub fn build(self) -> Daemon
where S: IsComplete,

Finish building and return the requested object

pub fn cluster(self, value: String) -> DaemonBuilder<SetCluster<S>>
where S::Cluster: IsUnset,

Optional (Some / Option setters). ComputeCluster resource ID that this daemon runs on for Horizon-backed cloud platforms. Kubernetes and Local runtimes ignore this field.

pub fn maybe_cluster( self, value: Option<String>, ) -> DaemonBuilder<SetCluster<S>>
where S::Cluster: IsUnset,

Optional (Some / Option setters). ComputeCluster resource ID that this daemon runs on for Horizon-backed cloud platforms. Kubernetes and Local runtimes ignore this field.

pub fn permissions(self, value: String) -> DaemonBuilder<SetPermissions<S>>
where S::Permissions: IsUnset,

Required.

pub fn code(self, value: DaemonCode) -> DaemonBuilder<SetCode<S>>
where S::Code: IsUnset,

Required.

pub fn cpu(self, value: ResourceSpec) -> DaemonBuilder<SetCpu<S>>
where S::Cpu: IsUnset,

Optional (Some / Option setters). Default: default_daemon_cpu().

CPU resource requirements for each daemon instance.

pub fn maybe_cpu(self, value: Option<ResourceSpec>) -> DaemonBuilder<SetCpu<S>>
where S::Cpu: IsUnset,

Optional (Some / Option setters). Default: default_daemon_cpu().

CPU resource requirements for each daemon instance.

pub fn memory(self, value: ResourceSpec) -> DaemonBuilder<SetMemory<S>>
where S::Memory: IsUnset,

Optional (Some / Option setters). Default: default_daemon_memory().

Memory resource requirements for each daemon instance.

pub fn maybe_memory( self, value: Option<ResourceSpec>, ) -> DaemonBuilder<SetMemory<S>>
where S::Memory: IsUnset,

Optional (Some / Option setters). Default: default_daemon_memory().

Memory resource requirements for each daemon instance.

pub fn pool(self, value: String) -> DaemonBuilder<SetPool<S>>
where S::Pool: IsUnset,

Optional (Some / Option setters). Capacity group/pool to run on for backends that expose machine pools.

pub fn maybe_pool(self, value: Option<String>) -> DaemonBuilder<SetPool<S>>
where S::Pool: IsUnset,

Optional (Some / Option setters). Capacity group/pool to run on for backends that expose machine pools.

pub fn command(self, value: Vec<String>) -> DaemonBuilder<SetCommand<S>>
where S::Command: IsUnset,

Optional (Some / Option setters). Command to override the image default.

pub fn maybe_command( self, value: Option<Vec<String>>, ) -> DaemonBuilder<SetCommand<S>>
where S::Command: IsUnset,

Optional (Some / Option setters). Command to override the image default.

pub fn environment( self, value: HashMap<String, String>, ) -> DaemonBuilder<SetEnvironment<S>>
where S::Environment: IsUnset,

Optional (Some / Option setters). Default: <HashMap<String, String> as Default>::default().

pub fn maybe_environment( self, value: Option<HashMap<String, String>>, ) -> DaemonBuilder<SetEnvironment<S>>
where S::Environment: IsUnset,

Optional (Some / Option setters). Default: <HashMap<String, String> as Default>::default().

pub fn commands_enabled( self, value: bool, ) -> DaemonBuilder<SetCommandsEnabled<S>>
where S::CommandsEnabled: IsUnset,

Optional (Some / Option setters). Default: default_commands_enabled().

pub fn maybe_commands_enabled( self, value: Option<bool>, ) -> DaemonBuilder<SetCommandsEnabled<S>>
where S::CommandsEnabled: IsUnset,

Optional (Some / Option setters). Default: default_commands_enabled().

Source

impl<S: State> DaemonBuilder<S>