DeploymentStateBuilder

Struct DeploymentStateBuilder 

pub struct DeploymentStateBuilder<S: State = Empty> { /* private fields */ }
Use builder syntax to set the inputs and finish with build().

Implementations

Source

impl<S: State> DeploymentStateBuilder<S>

pub fn build(self) -> DeploymentState
where S: IsComplete,

Finish building and return the requested object

pub fn status( self, value: DeploymentStatus, ) -> DeploymentStateBuilder<SetStatus<S>>
where S::Status: IsUnset,

Required.

Current lifecycle phase

pub fn platform(self, value: Platform) -> DeploymentStateBuilder<SetPlatform<S>>
where S::Platform: IsUnset,

Required.

Target cloud platform (AWS, GCP, Azure, Kubernetes)

pub fn current_release( self, value: ReleaseInfo, ) -> DeploymentStateBuilder<SetCurrentRelease<S>>
where S::CurrentRelease: IsUnset,

Optional (Some / Option setters). Currently deployed release (None for first deployment)

pub fn maybe_current_release( self, value: Option<ReleaseInfo>, ) -> DeploymentStateBuilder<SetCurrentRelease<S>>
where S::CurrentRelease: IsUnset,

Optional (Some / Option setters). Currently deployed release (None for first deployment)

pub fn target_release( self, value: ReleaseInfo, ) -> DeploymentStateBuilder<SetTargetRelease<S>>
where S::TargetRelease: IsUnset,

Optional (Some / Option setters). Target release to deploy (None when synced with current)

pub fn maybe_target_release( self, value: Option<ReleaseInfo>, ) -> DeploymentStateBuilder<SetTargetRelease<S>>
where S::TargetRelease: IsUnset,

Optional (Some / Option setters). Target release to deploy (None when synced with current)

pub fn stack_state( self, value: StackState, ) -> DeploymentStateBuilder<SetStackState<S>>
where S::StackState: IsUnset,

Optional (Some / Option setters). Infrastructure resource tracking (which resources exist, their status, outputs)

pub fn maybe_stack_state( self, value: Option<StackState>, ) -> DeploymentStateBuilder<SetStackState<S>>
where S::StackState: IsUnset,

Optional (Some / Option setters). Infrastructure resource tracking (which resources exist, their status, outputs)

pub fn environment_info( self, value: EnvironmentInfo, ) -> DeploymentStateBuilder<SetEnvironmentInfo<S>>
where S::EnvironmentInfo: IsUnset,

Optional (Some / Option setters). Cloud account details (account ID, project number, region)

pub fn maybe_environment_info( self, value: Option<EnvironmentInfo>, ) -> DeploymentStateBuilder<SetEnvironmentInfo<S>>
where S::EnvironmentInfo: IsUnset,

Optional (Some / Option setters). Cloud account details (account ID, project number, region)

pub fn runtime_metadata( self, value: RuntimeMetadata, ) -> DeploymentStateBuilder<SetRuntimeMetadata<S>>
where S::RuntimeMetadata: IsUnset,

Optional (Some / Option setters). Deployment-specific data (prepared stacks, phase tracking, etc.)

pub fn maybe_runtime_metadata( self, value: Option<RuntimeMetadata>, ) -> DeploymentStateBuilder<SetRuntimeMetadata<S>>
where S::RuntimeMetadata: IsUnset,

Optional (Some / Option setters). Deployment-specific data (prepared stacks, phase tracking, etc.)

pub fn retry_requested( self, value: bool, ) -> DeploymentStateBuilder<SetRetryRequested<S>>
where S::RetryRequested: IsUnset,

Required.

Whether a retry has been requested for a failed deployment When true and status is a failed state, the deployment system will retry failed resources