FunctionBuilder

Struct FunctionBuilder 

pub struct FunctionBuilder<S: State = Empty> { /* private fields */ }
Use builder syntax to set the inputs and finish with build().

Implementations

Source

impl<S: State> FunctionBuilder<S>

pub fn build(self) -> Function
where S: IsComplete,

Finish building and return the requested object

pub fn permissions(self, value: String) -> FunctionBuilder<SetPermissions<S>>
where S::Permissions: IsUnset,

Required.

Permission profile name that defines the permissions granted to this function. This references a profile defined in the stack’s permission definitions.

pub fn code(self, value: FunctionCode) -> FunctionBuilder<SetCode<S>>
where S::Code: IsUnset,

Required.

Code for the function, either a pre-built image or source code to be built.

pub fn memory_mb(self, value: u32) -> FunctionBuilder<SetMemoryMb<S>>
where S::MemoryMb: IsUnset,

Optional (Some / Option setters). Default: default_memory_mb().

Memory allocated to the function in megabytes (MB). Constraints: 128‑32768 MB (platform-specific limits may apply) Default: 256

pub fn maybe_memory_mb( self, value: Option<u32>, ) -> FunctionBuilder<SetMemoryMb<S>>
where S::MemoryMb: IsUnset,

Optional (Some / Option setters). Default: default_memory_mb().

Memory allocated to the function in megabytes (MB). Constraints: 128‑32768 MB (platform-specific limits may apply) Default: 256

pub fn timeout_seconds( self, value: u32, ) -> FunctionBuilder<SetTimeoutSeconds<S>>
where S::TimeoutSeconds: IsUnset,

Optional (Some / Option setters). Default: default_timeout_seconds().

Maximum execution time for the function in seconds. Constraints: 1‑3600 seconds (platform-specific limits may apply) Default: 30

pub fn maybe_timeout_seconds( self, value: Option<u32>, ) -> FunctionBuilder<SetTimeoutSeconds<S>>
where S::TimeoutSeconds: IsUnset,

Optional (Some / Option setters). Default: default_timeout_seconds().

Maximum execution time for the function in seconds. Constraints: 1‑3600 seconds (platform-specific limits may apply) Default: 30

pub fn environment( self, value: HashMap<String, String>, ) -> FunctionBuilder<SetEnvironment<S>>
where S::Environment: IsUnset,

Optional (Some / Option setters). Default: <HashMap<String, String> as Default>::default().

Key-value pairs to set as environment variables for the function.

pub fn maybe_environment( self, value: Option<HashMap<String, String>>, ) -> FunctionBuilder<SetEnvironment<S>>
where S::Environment: IsUnset,

Optional (Some / Option setters). Default: <HashMap<String, String> as Default>::default().

Key-value pairs to set as environment variables for the function.

pub fn ingress(self, value: Ingress) -> FunctionBuilder<SetIngress<S>>
where S::Ingress: IsUnset,

Optional (Some / Option setters). Default: default_ingress().

Controls network accessibility of the function.

pub fn maybe_ingress( self, value: Option<Ingress>, ) -> FunctionBuilder<SetIngress<S>>
where S::Ingress: IsUnset,

Optional (Some / Option setters). Default: default_ingress().

Controls network accessibility of the function.

pub fn arc_enabled(self, value: bool) -> FunctionBuilder<SetArcEnabled<S>>
where S::ArcEnabled: IsUnset,

Optional (Some / Option setters). Default: default_arc_enabled().

Whether the function can be invoked via ARC (Alien Remote Call) protocol from the control plane. When enabled, the necessary queue infrastructure is automatically created for the target platform.

pub fn maybe_arc_enabled( self, value: Option<bool>, ) -> FunctionBuilder<SetArcEnabled<S>>
where S::ArcEnabled: IsUnset,

Optional (Some / Option setters). Default: default_arc_enabled().

Whether the function can be invoked via ARC (Alien Remote Call) protocol from the control plane. When enabled, the necessary queue infrastructure is automatically created for the target platform.

pub fn concurrency_limit( self, value: u32, ) -> FunctionBuilder<SetConcurrencyLimit<S>>
where S::ConcurrencyLimit: IsUnset,

Optional (Some / Option setters). Maximum number of concurrent executions allowed for the function. None means platform default applies.

pub fn maybe_concurrency_limit( self, value: Option<u32>, ) -> FunctionBuilder<SetConcurrencyLimit<S>>
where S::ConcurrencyLimit: IsUnset,

Optional (Some / Option setters). Maximum number of concurrent executions allowed for the function. None means platform default applies.

pub fn readiness_probe( self, value: ReadinessProbe, ) -> FunctionBuilder<SetReadinessProbe<S>>
where S::ReadinessProbe: IsUnset,

Optional (Some / Option setters). Optional readiness probe configuration. Only applicable for functions with Public ingress. When configured, the probe will be executed after provisioning/update to verify the function is ready.

pub fn maybe_readiness_probe( self, value: Option<ReadinessProbe>, ) -> FunctionBuilder<SetReadinessProbe<S>>
where S::ReadinessProbe: IsUnset,

Optional (Some / Option setters). Optional readiness probe configuration. Only applicable for functions with Public ingress. When configured, the probe will be executed after provisioning/update to verify the function is ready.

Source

impl<S: State> FunctionBuilder<S>

Links the function to another resource with specified permissions. Accepts a reference to any type R where &R can be converted into ResourceRef.

pub fn trigger(self, trigger: FunctionTrigger) -> Self

Adds a trigger to the function. Functions can have multiple triggers. Each trigger will independently invoke the function when its conditions are met.

Examples
let function = Function::new("my-function".to_string())
    .code(FunctionCode::Image { image: "test:latest".to_string() })
    .permissions("execution".to_string())
    .trigger(FunctionTrigger::queue(&queue1))
    .trigger(FunctionTrigger::queue(&queue2))
    .build();