pub struct GcpImpersonationConfig {
pub service_account_email: String,
pub scopes: Vec<String>,
pub delegates: Option<Vec<String>>,
pub lifetime: Option<String>,
pub target_project_id: Option<String>,
pub target_region: Option<String>,
}Expand description
Configuration for GCP service account impersonation
Fields
service_account_email: StringThe email of the service account to impersonate
scopes: Vec<String>The OAuth 2.0 scopes that define the access token’s permissions
delegates: Option<Vec<String>>Optional sequence of service accounts in a delegation chain
lifetime: Option<String>Optional desired lifetime duration of the access token (max 3600s)
target_project_id: Option<String>Optional target project ID override. When provided, the impersonated config uses this project ID instead of inheriting the caller’s project.
target_region: Option<String>Optional target region override. When provided, the impersonated config uses this region instead of inheriting the caller’s region.