pub struct KubernetesClusterOutputs {Show 13 fields
pub provider: KubernetesClusterProvider,
pub ownership: KubernetesClusterOwnership,
pub namespace: String,
pub cluster_name: Option<String>,
pub cluster_id: Option<String>,
pub kubernetes_api_reachable: bool,
pub namespace_ready: bool,
pub rbac_ready: bool,
pub agent_ready: bool,
pub cloud_metadata_ready: Option<bool>,
pub azure_application_gateway_for_containers: Option<AzureApplicationGatewayForContainersBootstrap>,
pub version: Option<String>,
pub status_message: Option<String>,
}Expand description
Outputs produced once the Kubernetes substrate is ready for workloads.
Fields
provider: KubernetesClusterProviderownership: KubernetesClusterOwnershipnamespace: Stringcluster_name: Option<String>cluster_id: Option<String>kubernetes_api_reachable: boolnamespace_ready: boolrbac_ready: boolagent_ready: boolcloud_metadata_ready: Option<bool>azure_application_gateway_for_containers: Option<AzureApplicationGatewayForContainersBootstrap>version: Option<String>status_message: Option<String>Trait Implementations
Sourceimpl Clone for KubernetesClusterOutputs
impl Clone for KubernetesClusterOutputs
Sourcefn clone(&self) -> KubernetesClusterOutputs
fn clone(&self) -> KubernetesClusterOutputs
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for KubernetesClusterOutputs
impl Debug for KubernetesClusterOutputs
Sourceimpl<'de> Deserialize<'de> for KubernetesClusterOutputs
impl<'de> Deserialize<'de> for KubernetesClusterOutputs
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for KubernetesClusterOutputs
Sourceimpl PartialEq for KubernetesClusterOutputs
impl PartialEq for KubernetesClusterOutputs
Sourcefn eq(&self, other: &KubernetesClusterOutputs) -> bool
fn eq(&self, other: &KubernetesClusterOutputs) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl ResourceOutputsDefinition for KubernetesClusterOutputs
impl ResourceOutputsDefinition for KubernetesClusterOutputs
Sourcefn get_resource_type(&self) -> ResourceType
fn get_resource_type(&self) -> ResourceType
Returns the resource type for this instance
Sourcefn box_clone(&self) -> Box<dyn ResourceOutputsDefinition>
fn box_clone(&self) -> Box<dyn ResourceOutputsDefinition>
Creates a boxed clone of this resource outputs
Sourcefn outputs_eq(&self, other: &dyn ResourceOutputsDefinition) -> bool
fn outputs_eq(&self, other: &dyn ResourceOutputsDefinition) -> bool
For equality comparison between resource outputs
Sourcefn to_json_value(&self) -> Result<Value>
fn to_json_value(&self) -> Result<Value>
Serialize this resource outputs to a JSON value (without the “type” tag - that’s added by ResourceOutputs)
Sourceimpl Serialize for KubernetesClusterOutputs
impl Serialize for KubernetesClusterOutputs
impl StructuralPartialEq for KubernetesClusterOutputs