pub struct KubernetesGatewayRouteProfile {
pub controller: Option<String>,
pub gateway_class_name: String,
pub listener_port: u16,
pub labels: HashMap<String, String>,
pub annotations: HashMap<String, String>,
pub provider: Option<KubernetesRouteProviderOptions>,
}Expand description
Shared Gateway API route profile values.
Fields
controller: Option<String>Route controller identifier, for example a cloud Gateway controller.
gateway_class_name: StringGatewayClass selected for generated Gateways.
listener_port: u16Listener port, usually 443.
labels: HashMap<String, String>Labels applied to route objects.
annotations: HashMap<String, String>Annotations applied to route objects.
provider: Option<KubernetesRouteProviderOptions>Provider-specific route options that are required by the selected class.