pub struct KubernetesSettings {
pub cluster: Option<KubernetesClusterSettings>,
pub exposure: Option<KubernetesExposureSettings>,
}Expand description
Kubernetes runtime substrate configuration.
This controls how setup chooses the cluster backing Platform::Kubernetes
deployments. When omitted, cloud-backed Kubernetes deployments default to a
managed cluster and generic/on-prem Kubernetes defaults to an external
cluster.
Fields
cluster: Option<KubernetesClusterSettings>Cluster selection or creation settings.
exposure: Option<KubernetesExposureSettings>Public HTTPS exposure contract shared by setup, Helm, and runtime.