pub struct ObservedInventoryBatch {
pub source_kind: String,
pub inventory_scope: String,
pub controller_platform: Platform,
pub backend: HeartbeatBackend,
pub observed_at: DateTime<Utc>,
pub complete: bool,
pub resources: Vec<ObservedResourceSample>,
}Fields
source_kind: StringWriter/source for this inventory pass, such as operator or
manager-observer.
inventory_scope: StringStable scope for the provider list operation that produced this batch.
controller_platform: PlatformPlatform whose observer produced this snapshot.
backend: HeartbeatBackendBackend whose observer produced this snapshot.
observed_at: DateTime<Utc>Time the inventory scope was observed.
complete: boolWhether this batch is a complete replacement for the scope. Complete
batches tombstone previously observed rows in the same scope when they
are absent from resources.
resources: Vec<ObservedResourceSample>Trait Implementations
Sourceimpl Clone for ObservedInventoryBatch
impl Clone for ObservedInventoryBatch
Sourcefn clone(&self) -> ObservedInventoryBatch
fn clone(&self) -> ObservedInventoryBatch
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ObservedInventoryBatch
impl Debug for ObservedInventoryBatch
Sourceimpl<'de> Deserialize<'de> for ObservedInventoryBatch
impl<'de> Deserialize<'de> for ObservedInventoryBatch
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for ObservedInventoryBatch
impl PartialEq for ObservedInventoryBatch
Sourcefn eq(&self, other: &ObservedInventoryBatch) -> bool
fn eq(&self, other: &ObservedInventoryBatch) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for ObservedInventoryBatch
impl Serialize for ObservedInventoryBatch
impl StructuralPartialEq for ObservedInventoryBatch