pub struct ObservedResourceSample {Show 20 fields
pub deployment_id: Option<String>,
pub raw_identity: String,
pub provider_kind: String,
pub display_name: String,
pub namespace: Option<String>,
pub region: Option<String>,
pub scope: Option<String>,
pub resource_type_hint: Option<ResourceType>,
pub version: Option<String>,
pub alien_resource_id: Option<String>,
pub health: ObservedHealth,
pub lifecycle: ProviderLifecycleState,
pub message: Option<String>,
pub partial: bool,
pub provider_stale: bool,
pub counts: Option<ObservedCounts>,
pub collection_issues: Vec<HeartbeatCollectionIssue>,
pub labels: BTreeMap<String, String>,
pub attributes: BTreeMap<String, Value>,
pub raw: Vec<RawHeartbeatSnippet>,
}Fields
deployment_id: Option<String>raw_identity: StringProvider-native stable identity: Kubernetes object identity, cloud ARN, GCP full resource name, Azure resource id, etc.
provider_kind: StringProvider-native kind, such as apps/v1/Deployment,
AWS::S3::Bucket, storage.googleapis.com/Bucket, or an Azure
resource type.
display_name: Stringnamespace: Option<String>region: Option<String>scope: Option<String>resource_type_hint: Option<ResourceType>version: Option<String>Release/version identity observed from the provider resource, when available.
alien_resource_id: Option<String>health: ObservedHealthlifecycle: ProviderLifecycleStatemessage: Option<String>partial: boolprovider_stale: boolcounts: Option<ObservedCounts>collection_issues: Vec<HeartbeatCollectionIssue>labels: BTreeMap<String, String>attributes: BTreeMap<String, Value>raw: Vec<RawHeartbeatSnippet>Trait Implementations
Sourceimpl Clone for ObservedResourceSample
impl Clone for ObservedResourceSample
Sourcefn clone(&self) -> ObservedResourceSample
fn clone(&self) -> ObservedResourceSample
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ObservedResourceSample
impl Debug for ObservedResourceSample
Sourceimpl<'de> Deserialize<'de> for ObservedResourceSample
impl<'de> Deserialize<'de> for ObservedResourceSample
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for ObservedResourceSample
impl PartialEq for ObservedResourceSample
Sourcefn eq(&self, other: &ObservedResourceSample) -> bool
fn eq(&self, other: &ObservedResourceSample) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for ObservedResourceSample
impl Serialize for ObservedResourceSample
impl StructuralPartialEq for ObservedResourceSample