pub struct SandboxOutputs {
pub parent_name: String,
pub identifier: Option<String>,
pub endpoint: Option<String>,
}Expand description
Outputs generated by a successfully provisioned Sandbox parent.
Fields
parent_name: StringName of the durable parent that sessions are created inside
identifier: Option<String>Platform-specific identifier for the parent (image ARN, sandbox group id, namespace)
endpoint: Option<String>Data-plane endpoint sessions are created through, where the platform has one