pub struct ServiceActivation {
pub id: String,
pub service_name: String,
}Expand description
Represents a service activation that can be enabled on cloud platforms. For GCP: enables project services (e.g., iam.googleapis.com, compute.googleapis.com). For Azure: registers resource providers (e.g., Microsoft.DocumentDB, Microsoft.Storage).
Fields
id: StringIdentifier for the service activation. Must contain only alphanumeric characters, hyphens, and underscores ([A-Za-z0-9-_]). Maximum 64 characters.
service_name: StringThe service identifier to activate.
- For GCP: service name (e.g., “iam.googleapis.com”, “compute.googleapis.com”)
- For Azure: resource provider namespace (e.g., “Microsoft.DocumentDB”, “Microsoft.Storage”)
Implementations
Sourceimpl ServiceActivation
impl ServiceActivation
Sourcepub fn new(id: String) -> ServiceActivationBuilder
pub fn new(id: String) -> ServiceActivationBuilder
Create an instance of ServiceActivation using the builder syntax
Sourceimpl ServiceActivation
impl ServiceActivation
Sourcepub const RESOURCE_TYPE: ResourceType
pub const RESOURCE_TYPE: ResourceType
The resource type identifier for Service Activations