pub struct Storage {
pub id: String,
pub public_read: bool,
pub versioning: bool,
pub lifecycle_rules: Vec<LifecycleRule>,
pub cors_allowed_origins: Vec<String>,
pub encryption_key: Option<ResourceRef>,
}Expand description
Represents an object storage bucket.
Fields
id: StringName of the the storage bucket. For names with dots, each dot-separated label must be ≤ 63 characters.
public_read: boolAllows public read access to objects without authentication.
Default: false
versioning: boolEnables object versioning.
Default: false
lifecycle_rules: Vec<LifecycleRule>List of rules for automatic object management (e.g., expiration).
Default: [] (empty list)
cors_allowed_origins: Vec<String>Browser origins allowed to read objects through signed URLs.
When non-empty, providers configure CORS for GET and HEAD requests.
An origin of * is appropriate for private buckets whose signed URLs
are bearer credentials and do not use browser cookies.
Default: [] (CORS disabled).
encryption_key: Option<ResourceRef>Customer-managed Key used by the provider’s native storage encryption.
Implementations
Sourceimpl Storage
impl Storage
Sourcepub fn new(id: String) -> StorageBuilder
pub fn new(id: String) -> StorageBuilder
Create an instance of Storage using the builder syntax
Sourceimpl Storage
impl Storage
Sourcepub const RESOURCE_TYPE: ResourceType
pub const RESOURCE_TYPE: ResourceType
The resource type identifier for Storage