pub struct VolumeRestoreOutput {
pub request_id: String,
pub snapshot_id: String,
pub replaced_volume_snapshot_id: String,
pub completed_at: String,
}Expand description
A completed volume restore.
Fields
request_id: StringID of the restore request
snapshot_id: StringSnapshot the volume was restored from
replaced_volume_snapshot_id: StringSnapshot of the replaced volume, taken just before it was deleted
completed_at: StringWhen the restored volume was put in place (RFC 3339)