pub enum OperatorCapabilityState {
Granted,
Denied,
Unavailable,
}Expand description
State of an Operator capability as observed inside the environment.
Variants
Granted
The Operator has the permission or local facility needed for the capability.
Denied
The environment explicitly denied the capability.
The capability does not apply in this environment.