pub struct SyncInputBuilder { /* private fields */ }Expand description
Builder for optional sync receipts. New optional wire metadata belongs
here so adding it does not break downstream SyncRequest literals.
Implementations
Sourceimpl SyncInputBuilder
impl SyncInputBuilder
Sourcepub fn operator_image(self, operator_image: OperatorImageReport) -> Self
pub fn operator_image(self, operator_image: OperatorImageReport) -> Self
Attach the immutable image receipt for the running Operator.
Sourcepub fn application(self, application: ObservedApplicationReport) -> Self
pub fn application(self, application: ObservedApplicationReport) -> Self
Attach the application release observed in the environment.
pub fn dynamic_containers(self, reports: Vec<DynamicContainerReport>) -> Self