ResourceLinks

Trait ResourceLinks 

pub trait ResourceLinks {
    // Required methods
    fn links(&self) -> &[ResourceRef];
    fn links_mut(&mut self) -> &mut Vec<ResourceRef>;
}
A resource definition that owns resource links.

Required Methods

The links this definition owns, excluding triggers and ordering edges.

Mutable access, for dropping links to resources leaving the stack.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors