pub enum SandboxBinding {
Aws(AwsSandboxBinding),
Azure(AzureSandboxBinding),
GcpAgentPlatform(GcpAgentPlatformSandboxBinding),
Kubernetes(KubernetesSandboxBinding),
Local(LocalSandboxBinding),
}Expand description
Represents a sandbox binding for creating and reaching sandboxes.
Service tags are prefixed with sandbox- because serde selects the variant on the service
field alone. An unprefixed local would deserialize as another resource’s local binding by
silently dropping the fields that differ.
Variants
Aws(AwsSandboxBinding)
AWS Lambda MicroVM sandboxes
Azure(AzureSandboxBinding)
Azure Container Apps Sandboxes
GcpAgentPlatform(GcpAgentPlatformSandboxBinding)
GCP Agent Platform sandboxes, created under a durable Agent Engine
Kubernetes(KubernetesSandboxBinding)
Sandbox pods under a sandboxed runtime class
Local(LocalSandboxBinding)
Local Docker sandboxes managed by the local sandbox manager
Implementations
Sourceimpl SandboxBinding
impl SandboxBinding
Sourcepub fn aws(
image_arn: impl Into<BindingValue<String>>,
image_version: impl Into<BindingValue<String>>,
region: impl Into<BindingValue<String>>,
) -> Self
pub fn aws( image_arn: impl Into<BindingValue<String>>, image_version: impl Into<BindingValue<String>>, region: impl Into<BindingValue<String>>, ) -> Self
Creates an AWS sandbox binding.
Sourcepub fn azure(
sandbox_group: impl Into<BindingValue<String>>,
data_plane_endpoint: impl Into<BindingValue<String>>,
region: impl Into<BindingValue<String>>,
resource_group: impl Into<BindingValue<String>>,
disk_image: impl Into<BindingValue<String>>,
egress: SandboxEgress,
idle_pause_seconds: Option<u32>,
) -> Self
pub fn azure( sandbox_group: impl Into<BindingValue<String>>, data_plane_endpoint: impl Into<BindingValue<String>>, region: impl Into<BindingValue<String>>, resource_group: impl Into<BindingValue<String>>, disk_image: impl Into<BindingValue<String>>, egress: SandboxEgress, idle_pause_seconds: Option<u32>, ) -> Self
Creates an Azure sandbox binding.
Sourcepub fn gcp_agent_platform(
engine: impl Into<BindingValue<String>>,
template: impl Into<BindingValue<String>>,
region: impl Into<BindingValue<String>>,
max_lifetime_seconds: Option<u32>,
) -> Self
pub fn gcp_agent_platform( engine: impl Into<BindingValue<String>>, template: impl Into<BindingValue<String>>, region: impl Into<BindingValue<String>>, max_lifetime_seconds: Option<u32>, ) -> Self
Creates a GCP Agent Platform sandbox binding.
Sourcepub fn kubernetes(
namespace: impl Into<BindingValue<String>>,
runtime_class: impl Into<BindingValue<String>>,
selector: impl Into<BindingValue<String>>,
broker_url: impl Into<BindingValue<String>>,
key_name: impl Into<BindingValue<String>>,
token_path: impl Into<BindingValue<String>>,
) -> Self
pub fn kubernetes( namespace: impl Into<BindingValue<String>>, runtime_class: impl Into<BindingValue<String>>, selector: impl Into<BindingValue<String>>, broker_url: impl Into<BindingValue<String>>, key_name: impl Into<BindingValue<String>>, token_path: impl Into<BindingValue<String>>, ) -> Self
Creates a Kubernetes sandbox binding.
Sourcepub fn local(
manager_url: impl Into<BindingValue<String>>,
sandbox_key: impl Into<BindingValue<String>>,
token_path: impl Into<BindingValue<String>>,
) -> Self
pub fn local( manager_url: impl Into<BindingValue<String>>, sandbox_key: impl Into<BindingValue<String>>, token_path: impl Into<BindingValue<String>>, ) -> Self
Creates a local sandbox binding.