CargoBuildStrategy

Enum CargoBuildStrategy 

pub enum CargoBuildStrategy {
    Native,
    Zigbuild,
    Xwin,
}
Build strategy for cross-compilation.

Variants



Native

Plain cargo build — native toolchain, no cross-compilation.



Zigbuild

cargo zigbuild — uses Zig as the C toolchain for Linux musl targets.



Xwin

cargo xwin build — uses xwin to provide MSVC CRT/SDK for Windows targets from non-Windows hosts.

Implementations

Source

impl CargoBuildStrategy

pub fn cargo_subcommand(&self) -> &'static str

The cargo subcommand to use (e.g. “build”, “zigbuild”, “xwin”).

pub fn cargo_args(&self) -> Vec<&'static str>

Cargo args: for xwin, the subcommand is cargo xwin build (two args).

pub fn display_name(&self) -> &'static str

Human-readable name for logging.

pub fn install_package(&self) -> Option<&'static str>

The cargo tool binary to install (None for native builds).