pub enum DeploymentStatus {
Show 14 variants
Pending,
InitialSetup,
InitialSetupFailed,
Provisioning,
ProvisioningFailed,
Running,
RefreshFailed,
UpdatePending,
Updating,
UpdateFailed,
DeletePending,
Deleting,
DeleteFailed,
Deleted,
}Expand description
Deployment status in the deployment lifecycle
Variants
Pending
InitialSetup
InitialSetupFailed
Provisioning
ProvisioningFailed
Running
RefreshFailed
UpdatePending
Updating
UpdateFailed
DeletePending
Deleting
DeleteFailed
Deleted
Implementations
Sourceimpl DeploymentStatus
impl DeploymentStatus
Sourcepub fn is_synced(&self) -> bool
pub fn is_synced(&self) -> bool
Check if deployment is synced (current state matches desired state).
When synced, no more deployment steps are needed for the current operation. Note: This doesn’t mean the deployment is “done forever”:
Running→ heartbeats continue, updates can come*Failed→ can be retriedDeleted→ can be recreated
“Synced” means: “we’ve reached the goal of the current deployment phase”