pub enum SandboxCode {
Image {
image: String,
},
Source {
src: String,
toolchain: ToolchainConfig,
},
}Expand description
Specifies where the sandbox’s root filesystem comes from.
Variants
Image
A prebuilt container image used as the sandbox root filesystem.
Source built into a sandbox image at deploy time.
Fields

toolchain: ToolchainConfigToolchain configuration with type-safe options