AlienEvent

Enum AlienEvent 

pub enum AlienEvent {
Show 31 variants LoadingConfiguration, Finished, BuildingStack { stack: String, }, RunningPreflights { stack: String, platform: String, }, DownloadingAlienRuntime { target_triple: String, url: String, }, BuildingResource { resource_name: String, resource_type: String, related_resources: Vec<String>, }, BuildingImage { image: String, }, PushingImage { image: String, progress: Option<PushProgress>, }, PushingStack { stack: String, platform: String, }, PushingResource { resource_name: String, resource_type: String, }, CreatingRelease { project: String, }, CompilingCode { language: String, progress: Option<String>, }, StackStep { next_state: StackState, suggested_delay_ms: Option<u64>, }, GeneratingCloudFormationTemplate, GeneratingTemplate { platform: String, }, ProvisioningAgent { agent_id: String, release_id: String, }, UpdatingAgent { agent_id: String, release_id: String, }, DeletingAgent { agent_id: String, release_id: String, }, DebuggingAgent { agent_id: String, debug_session_id: String, }, PreparingEnvironment { strategy_name: String, }, DeployingStack { stack_name: String, }, RunningTestFunction { stack_name: String, }, CleaningUpStack { stack_name: String, strategy_name: String, }, CleaningUpEnvironment { stack_name: String, strategy_name: String, }, SettingUpPlatformContext { platform_name: String, }, EnsuringDockerRepository { repository_name: String, }, DeployingCloudFormationStack { cfn_stack_name: String, current_status: String, }, AssumingRole { role_arn: String, }, ImportingStackStateFromCloudFormation { cfn_stack_name: String, }, DeletingCloudFormationStack { cfn_stack_name: String, current_status: String, }, EmptyingBuckets { bucket_names: Vec<String>, },
}
Represents all possible events in the Alien system

Variants



LoadingConfiguration

Loading configuration file



Finished

Operation finished successfully



BuildingStack

Stack packaging event

Fields

stack: String

Name of the stack being built



RunningPreflights

Running build-time preflight checks and mutations

Fields

stack: String

Name of the stack being checked

platform: String

Platform being targeted



DownloadingAlienRuntime

Downloading alien runtime event

Fields

target_triple: String

Target triple for the runtime

url: String

URL being downloaded from



BuildingResource

Resource build event (function, container, or worker)

Fields

resource_name: String

Name of the resource being built

resource_type: String

Type of the resource: “function”, “container”, “worker”

related_resources: Vec<String>

All resource names sharing this build (for deduped container groups)



BuildingImage

Image build event

Fields

image: String

Name of the image being built



PushingImage

Image push event

Fields

image: String

Name of the image being pushed

progress: Option<PushProgress>

Progress information for the push operation



PushingStack

Pushing stack images to registry

Fields

stack: String

Name of the stack being pushed

platform: String

Target platform



PushingResource

Pushing resource images to registry

Fields

resource_name: String

Name of the resource being pushed

resource_type: String

Type of the resource: “function”, “container”, “worker”



CreatingRelease

Creating a release on the platform

Fields

project: String

Project name



CompilingCode

Code compilation event (rust, typescript, etc.)

Fields

language: String

Language being compiled (rust, typescript, etc.)

progress: Option<String>

Current progress/status line from the build output



StackStep

Fields

next_state: StackState

The resulting state of the stack after the step.

suggested_delay_ms: Option<u64>

An suggested duration to wait before executing the next step.



GeneratingCloudFormationTemplate

Generating CloudFormation template



GeneratingTemplate

Generating infrastructure template

Fields

platform: String

Platform for which the template is being generated



ProvisioningAgent

Provisioning a new agent

Fields

agent_id: String

ID of the agent being provisioned

release_id: String

ID of the release being deployed to the agent



UpdatingAgent

Updating an existing agent

Fields

agent_id: String

ID of the agent being updated

release_id: String

ID of the new release being deployed to the agent



DeletingAgent

Deleting an agent

Fields

agent_id: String

ID of the agent being deleted

release_id: String

ID of the release that was running on the agent



DebuggingAgent

Starting a debug session for an agent

Fields

agent_id: String

ID of the agent being debugged

debug_session_id: String

ID of the debug session



PreparingEnvironment

Preparing environment for deployment

Fields

strategy_name: String

Name of the deployment strategy being used



DeployingStack

Deploying stack with alien-infra

Fields

stack_name: String

Name of the stack being deployed



RunningTestFunction

Running test function after deployment

Fields

stack_name: String

Name of the stack being tested



CleaningUpStack

Cleaning up deployed stack resources

Fields

stack_name: String

Name of the stack being cleaned up

strategy_name: String

Name of the deployment strategy being used for cleanup



CleaningUpEnvironment

Cleaning up deployment environment

Fields

stack_name: String

Name of the stack being cleaned up

strategy_name: String

Name of the deployment strategy being used for cleanup



SettingUpPlatformContext

Setting up platform context

Fields

platform_name: String

Name of the platform (e.g., “AWS”, “GCP”)



EnsuringDockerRepository

Ensuring docker repository exists

Fields

repository_name: String

Name of the docker repository



DeployingCloudFormationStack

Deploying CloudFormation stack

Fields

cfn_stack_name: String

Name of the CloudFormation stack

current_status: String

Current stack status



AssumingRole

Assuming AWS IAM role

Fields

role_arn: String

ARN of the role to assume



ImportingStackStateFromCloudFormation

Importing stack state from CloudFormation

Fields

cfn_stack_name: String

Name of the CloudFormation stack



DeletingCloudFormationStack

Deleting CloudFormation stack

Fields

cfn_stack_name: String

Name of the CloudFormation stack

current_status: String

Current stack status



EmptyingBuckets

Emptying S3 buckets before stack deletion

Fields

bucket_names: Vec<String>

Names of the S3 buckets being emptied

Implementations

Source

impl AlienEvent

pub async fn emit(self) -> Result<EventHandle>

Emit this event and wait for it to be handled

pub async fn emit_with_state(self, state: EventState) -> Result<EventHandle>

Emit this event with a specific initial state

pub async fn emit_with_parent(self, parent_id: &str) -> Result<EventHandle>

Emit this event as a child of another event

pub async fn in_scope<F, Fut, T, E>(self, f: F) -> Result<T, AlienError<E>>
where F: FnOnce(EventHandle) -> Fut, Fut: Future<Output = Result<T, AlienError<E>>>, E: AlienErrorData + Clone + Debug + Serialize + Send + Sync + 'static,

Start a scoped event that will track success/failure All events emitted within the scope will automatically be children of this event