pub struct Build {
pub id: String,
pub links: Vec<ResourceRef>,
pub permissions: String,
pub environment: HashMap<String, String>,
pub compute_type: ComputeType,
}Expand description
Represents a build resource that executes bash scripts to build code. Builds are designed to be stateless and can be triggered on-demand to compile, test, or package application code.
Fields
id: StringIdentifier for the build resource. Must contain only alphanumeric characters, hyphens, and underscores ([A-Za-z0-9-_]). Maximum 64 characters.
links: Vec<ResourceRef>List of resource references this build depends on.
permissions: StringPermission profile name that defines the permissions granted to this build. This references a profile defined in the stack’s permission definitions.
environment: HashMap<String, String>Key-value pairs to set as environment variables for the build.
compute_type: ComputeTypeAmount of compute resources allocated to the build.
Implementations
Sourceimpl Build
impl Build
Sourcepub fn new(id: String) -> BuildBuilder
pub fn new(id: String) -> BuildBuilder
Create an instance of Build using the builder syntax
Sourceimpl Build
impl Build
Sourcepub const RESOURCE_TYPE: ResourceType
pub const RESOURCE_TYPE: ResourceType
The resource type identifier for Builds
Sourcepub fn get_permissions(&self) -> &str
pub fn get_permissions(&self) -> &str
Returns the permission profile name for this build.