BuildBuilder

Struct BuildBuilder 

pub struct BuildBuilder<S: State = Empty> { /* private fields */ }
Use builder syntax to set the inputs and finish with build().

Implementations

Source

impl<S: State> BuildBuilder<S>

pub fn build(self) -> Build
where S: IsComplete,

Finish building and return the requested object

pub fn permissions(self, value: String) -> BuildBuilder<SetPermissions<S>>
where S::Permissions: IsUnset,

Required.

Permission profile name that defines the permissions granted to this build. This references a profile defined in the stack’s permission definitions.

pub fn environment( self, value: HashMap<String, String>, ) -> BuildBuilder<SetEnvironment<S>>
where S::Environment: IsUnset,

Optional (Some / Option setters). Default: <HashMap<String, String> as Default>::default().

Key-value pairs to set as environment variables for the build.

pub fn maybe_environment( self, value: Option<HashMap<String, String>>, ) -> BuildBuilder<SetEnvironment<S>>
where S::Environment: IsUnset,

Optional (Some / Option setters). Default: <HashMap<String, String> as Default>::default().

Key-value pairs to set as environment variables for the build.

pub fn compute_type(self, value: ComputeType) -> BuildBuilder<SetComputeType<S>>
where S::ComputeType: IsUnset,

Optional (Some / Option setters). Default: <ComputeType as Default>::default().

Amount of compute resources allocated to the build.

pub fn maybe_compute_type( self, value: Option<ComputeType>, ) -> BuildBuilder<SetComputeType<S>>
where S::ComputeType: IsUnset,

Optional (Some / Option setters). Default: <ComputeType as Default>::default().

Amount of compute resources allocated to the build.

Source

impl<S: State> BuildBuilder<S>

Links the build to another resource with specified permissions. Accepts a reference to any type R where &R can be converted into ResourceRef.