ContainerBuilder

Struct ContainerBuilder 

pub struct ContainerBuilder<S: State = Empty> { /* private fields */ }
Use builder syntax to set the inputs and finish with build().

Implementations

Source

impl<S: State> ContainerBuilder<S>

pub fn build(self) -> Container
where S: IsComplete,

Finish building and return the requested object

pub fn cluster(self, value: String) -> ContainerBuilder<SetCluster<S>>
where S::Cluster: IsUnset,

Optional (Some / Option setters).

ContainerCluster resource ID that this container runs on. If None, will be auto-assigned by ContainerClusterMutation at deployment time.

pub fn maybe_cluster( self, value: Option<String>, ) -> ContainerBuilder<SetCluster<S>>
where S::Cluster: IsUnset,

Optional (Some / Option setters).

ContainerCluster resource ID that this container runs on. If None, will be auto-assigned by ContainerClusterMutation at deployment time.

pub fn code(self, value: ContainerCode) -> ContainerBuilder<SetCode<S>>
where S::Code: IsUnset,

Required.

Container code (image or source)

pub fn cpu(self, value: ResourceSpec) -> ContainerBuilder<SetCpu<S>>
where S::Cpu: IsUnset,

Required.

CPU resource requirements

pub fn memory(self, value: ResourceSpec) -> ContainerBuilder<SetMemory<S>>
where S::Memory: IsUnset,

Required.

Memory resource requirements (must use Ki/Mi/Gi/Ti suffix)

pub fn gpu(self, value: ContainerGpuSpec) -> ContainerBuilder<SetGpu<S>>
where S::Gpu: IsUnset,

Optional (Some / Option setters).

GPU requirements (optional)

pub fn maybe_gpu( self, value: Option<ContainerGpuSpec>, ) -> ContainerBuilder<SetGpu<S>>
where S::Gpu: IsUnset,

Optional (Some / Option setters).

GPU requirements (optional)

pub fn ephemeral_storage( self, value: String, ) -> ContainerBuilder<SetEphemeralStorage<S>>
where S::EphemeralStorage: IsUnset,

Optional (Some / Option setters).

Ephemeral storage requirement (e.g., “10Gi”)

pub fn maybe_ephemeral_storage( self, value: Option<String>, ) -> ContainerBuilder<SetEphemeralStorage<S>>
where S::EphemeralStorage: IsUnset,

Optional (Some / Option setters).

Ephemeral storage requirement (e.g., “10Gi”)

pub fn persistent_storage( self, value: PersistentStorage, ) -> ContainerBuilder<SetPersistentStorage<S>>
where S::PersistentStorage: IsUnset,

Optional (Some / Option setters).

Persistent storage configuration (only for stateful containers)

pub fn maybe_persistent_storage( self, value: Option<PersistentStorage>, ) -> ContainerBuilder<SetPersistentStorage<S>>
where S::PersistentStorage: IsUnset,

Optional (Some / Option setters).

Persistent storage configuration (only for stateful containers)

pub fn replicas(self, value: u32) -> ContainerBuilder<SetReplicas<S>>
where S::Replicas: IsUnset,

Optional (Some / Option setters).

Fixed replica count (for stateful containers or stateless without autoscaling)

pub fn maybe_replicas( self, value: Option<u32>, ) -> ContainerBuilder<SetReplicas<S>>
where S::Replicas: IsUnset,

Optional (Some / Option setters).

Fixed replica count (for stateful containers or stateless without autoscaling)

pub fn autoscaling( self, value: ContainerAutoscaling, ) -> ContainerBuilder<SetAutoscaling<S>>
where S::Autoscaling: IsUnset,

Optional (Some / Option setters).

Autoscaling configuration (only for stateless containers)

pub fn maybe_autoscaling( self, value: Option<ContainerAutoscaling>, ) -> ContainerBuilder<SetAutoscaling<S>>
where S::Autoscaling: IsUnset,

Optional (Some / Option setters).

Autoscaling configuration (only for stateless containers)

pub fn stateful(self, value: bool) -> ContainerBuilder<SetStateful<S>>
where S::Stateful: IsUnset,

Optional (Some / Option setters). Default: false.

Whether container is stateful (gets stable ordinals, optional persistent volumes)

pub fn maybe_stateful( self, value: Option<bool>, ) -> ContainerBuilder<SetStateful<S>>
where S::Stateful: IsUnset,

Optional (Some / Option setters). Default: false.

Whether container is stateful (gets stable ordinals, optional persistent volumes)

pub fn environment( self, value: HashMap<String, String>, ) -> ContainerBuilder<SetEnvironment<S>>
where S::Environment: IsUnset,

Optional (Some / Option setters). Default: <HashMap<String, String> as Default>::default().

Environment variables

pub fn maybe_environment( self, value: Option<HashMap<String, String>>, ) -> ContainerBuilder<SetEnvironment<S>>
where S::Environment: IsUnset,

Optional (Some / Option setters). Default: <HashMap<String, String> as Default>::default().

Environment variables

pub fn pool(self, value: String) -> ContainerBuilder<SetPool<S>>
where S::Pool: IsUnset,

Optional (Some / Option setters).

Capacity group to run on (must exist in the cluster) If not specified, containers are scheduled to any available group.

pub fn maybe_pool(self, value: Option<String>) -> ContainerBuilder<SetPool<S>>
where S::Pool: IsUnset,

Optional (Some / Option setters).

Capacity group to run on (must exist in the cluster) If not specified, containers are scheduled to any available group.

pub fn permissions(self, value: String) -> ContainerBuilder<SetPermissions<S>>
where S::Permissions: IsUnset,

Required.

Permission profile name

pub fn health_check( self, value: HealthCheck, ) -> ContainerBuilder<SetHealthCheck<S>>
where S::HealthCheck: IsUnset,

Optional (Some / Option setters).

Health check configuration

pub fn maybe_health_check( self, value: Option<HealthCheck>, ) -> ContainerBuilder<SetHealthCheck<S>>
where S::HealthCheck: IsUnset,

Optional (Some / Option setters).

Health check configuration

pub fn command(self, value: Vec<String>) -> ContainerBuilder<SetCommand<S>>
where S::Command: IsUnset,

Optional (Some / Option setters).

Command to override image default

pub fn maybe_command( self, value: Option<Vec<String>>, ) -> ContainerBuilder<SetCommand<S>>
where S::Command: IsUnset,

Optional (Some / Option setters).

Command to override image default

Source

impl<S: State> ContainerBuilder<S>

Links the container to another resource with specified permissions.

pub fn port(self, port: u16) -> Self

Adds an internal-only port to the container.

pub fn expose_port(self, port: u16, protocol: ExposeProtocol) -> Self

Exposes a specific port publicly via load balancer.