pub struct Daemon {Show 14 fields
pub id: String,
pub links: Vec<ResourceRef>,
pub public_endpoints: Vec<PublicEndpoint>,
pub health_check: Option<HealthCheck>,
pub cluster: Option<String>,
pub permissions: String,
pub code: DaemonCode,
pub cpu: ResourceSpec,
pub memory: ResourceSpec,
pub pool: Option<String>,
pub command: Option<Vec<String>>,
pub runtime: Option<DaemonRuntime>,
pub environment: HashMap<String, String>,
pub commands_enabled: bool,
}Fields
id: Stringlinks: Vec<ResourceRef>public_endpoints: Vec<PublicEndpoint>Public endpoints exposed by the daemon.
health_check: Option<HealthCheck>HTTP health check for public daemon endpoint load balancers.
cluster: Option<String>ComputeCluster resource ID that this daemon runs on for managed cloud compute backends. Kubernetes and Local runtimes ignore this field.
permissions: Stringcode: DaemonCodecpu: ResourceSpecCPU resource requirements for each daemon instance.
memory: ResourceSpecMemory resource requirements for each daemon instance.
pool: Option<String>Capacity group/pool to run on for backends that expose machine pools.
command: Option<Vec<String>>Command to override the image default.
runtime: Option<DaemonRuntime>Optional backend runtime settings for trusted daemons.
These settings are intended for daemon-style infrastructure that must operate on the host. Backends that do not support a setting may reject it during provisioning.
environment: HashMap<String, String>commands_enabled: boolImplementations
Sourceimpl Daemon
impl Daemon
Sourcepub fn new(id: String) -> DaemonBuilder
pub fn new(id: String) -> DaemonBuilder
Create an instance of Daemon using the builder syntax
Sourceimpl Daemon
impl Daemon
pub const RESOURCE_TYPE: ResourceType
pub fn get_permissions(&self) -> &str