DeploymentConfigBuilder

Struct DeploymentConfigBuilder 

pub struct DeploymentConfigBuilder<S: State = Empty> { /* private fields */ }
Use builder syntax to set the inputs and finish with build().

Implementations

Source

impl<S: State> DeploymentConfigBuilder<S>

pub fn build(self) -> DeploymentConfig
where S: IsComplete,

Finish building and return the requested object

pub fn stack_settings( self, value: StackSettings, ) -> DeploymentConfigBuilder<SetStackSettings<S>>
where S::StackSettings: IsUnset,

Required.

User-customizable deployment settings (network, deployment model, approvals). Provided by customer via CloudFormation, Terraform, CLI, or Helm.

pub fn management_config( self, value: ManagementConfig, ) -> DeploymentConfigBuilder<SetManagementConfig<S>>
where S::ManagementConfig: IsUnset,

Optional (Some / Option setters). Platform service account/role that will manage the infrastructure remotely. Derived from Manager’s ServiceAccount, not user-specified.

pub fn maybe_management_config( self, value: Option<ManagementConfig>, ) -> DeploymentConfigBuilder<SetManagementConfig<S>>
where S::ManagementConfig: IsUnset,

Optional (Some / Option setters). Platform service account/role that will manage the infrastructure remotely. Derived from Manager’s ServiceAccount, not user-specified.

pub fn environment_variables( self, value: EnvironmentVariablesSnapshot, ) -> DeploymentConfigBuilder<SetEnvironmentVariables<S>>
where S::EnvironmentVariables: IsUnset,

Required.

Environment variables snapshot

pub fn allow_frozen_changes( self, value: bool, ) -> DeploymentConfigBuilder<SetAllowFrozenChanges<S>>
where S::AllowFrozenChanges: IsUnset,

Required.

Allow frozen resource changes during updates When true, skips the frozen resources compatibility check. This requires running with elevated cloud credentials.

pub fn compute_backend( self, value: ComputeBackend, ) -> DeploymentConfigBuilder<SetComputeBackend<S>>
where S::ComputeBackend: IsUnset,

Optional (Some / Option setters). Compute backend for Container and Function resources. When None, the platform default is used (Horizon for cloud platforms). Contains cluster IDs and management tokens for container orchestration. Machine tokens are stored in environment_variables as built-in secret vars.

pub fn maybe_compute_backend( self, value: Option<ComputeBackend>, ) -> DeploymentConfigBuilder<SetComputeBackend<S>>
where S::ComputeBackend: IsUnset,

Optional (Some / Option setters). Compute backend for Container and Function resources. When None, the platform default is used (Horizon for cloud platforms). Contains cluster IDs and management tokens for container orchestration. Machine tokens are stored in environment_variables as built-in secret vars.

pub fn external_bindings( self, value: ExternalBindings, ) -> DeploymentConfigBuilder<SetExternalBindings<S>>
where S::ExternalBindings: IsUnset,

Required.

External bindings for pre-existing services. Required for Kubernetes platform (all infrastructure resources). Optional for cloud platforms (override specific resources).

pub fn public_urls( self, value: HashMap<String, String>, ) -> DeploymentConfigBuilder<SetPublicUrls<S>>
where S::PublicUrls: IsUnset,

Optional (Some / Option setters). Public URLs for exposed resources (optional override for all platforms).

  • Kubernetes: Pre-computed by Helm from services config (highly recommended)
  • Cloud: Optional override of domain_metadata or load balancer DNS
  • Local: Optional override of dynamic localhost URLs

If not set, platforms determine public URLs from other sources:

  • Cloud: domain_metadata FQDN or load balancer DNS
  • Local: http://localhost:{allocated_port}
  • Kubernetes: None (unless provided by Helm)

Key: resource ID, Value: public URL (e.g., “https://api.acme.com”)

pub fn maybe_public_urls( self, value: Option<HashMap<String, String>>, ) -> DeploymentConfigBuilder<SetPublicUrls<S>>
where S::PublicUrls: IsUnset,

Optional (Some / Option setters). Public URLs for exposed resources (optional override for all platforms).

  • Kubernetes: Pre-computed by Helm from services config (highly recommended)
  • Cloud: Optional override of domain_metadata or load balancer DNS
  • Local: Optional override of dynamic localhost URLs

If not set, platforms determine public URLs from other sources:

  • Cloud: domain_metadata FQDN or load balancer DNS
  • Local: http://localhost:{allocated_port}
  • Kubernetes: None (unless provided by Helm)

Key: resource ID, Value: public URL (e.g., “https://api.acme.com”)

pub fn domain_metadata( self, value: DomainMetadata, ) -> DeploymentConfigBuilder<SetDomainMetadata<S>>
where S::DomainMetadata: IsUnset,

Optional (Some / Option setters). Domain metadata for auto-managed public resources (AWS/GCP/Azure). Contains certificate data for cloud provider import and renewal detection. Not used by Kubernetes (uses TLS Secrets) or Local (no TLS) platforms.

pub fn maybe_domain_metadata( self, value: Option<DomainMetadata>, ) -> DeploymentConfigBuilder<SetDomainMetadata<S>>
where S::DomainMetadata: IsUnset,

Optional (Some / Option setters). Domain metadata for auto-managed public resources (AWS/GCP/Azure). Contains certificate data for cloud provider import and renewal detection. Not used by Kubernetes (uses TLS Secrets) or Local (no TLS) platforms.

pub fn monitoring( self, value: OtlpConfig, ) -> DeploymentConfigBuilder<SetMonitoring<S>>
where S::Monitoring: IsUnset,

Optional (Some / Option setters). OTLP observability configuration for log export (optional).

When set, alien-deployment injects OTEL_EXPORTER_OTLP_* env vars into container/function configs, and alien-infra embeds –otlp-logs-* flags into horizond VM startup scripts.

pub fn maybe_monitoring( self, value: Option<OtlpConfig>, ) -> DeploymentConfigBuilder<SetMonitoring<S>>
where S::Monitoring: IsUnset,

Optional (Some / Option setters). OTLP observability configuration for log export (optional).

When set, alien-deployment injects OTEL_EXPORTER_OTLP_* env vars into container/function configs, and alien-infra embeds –otlp-logs-* flags into horizond VM startup scripts.

pub fn manager_url( self, value: String, ) -> DeploymentConfigBuilder<SetManagerUrl<S>>
where S::ManagerUrl: IsUnset,

Optional (Some / Option setters). Manager base URL (e.g., “https://manager.alien.dev”).

The manager IS the container registry — its /v2/ endpoint serves as the OCI Distribution API. Controllers derive the proxy host from this to configure pull auth (RegistryCredentials, imagePullSecrets).

When None (e.g., alien dev), controllers use image URIs as-is.

pub fn maybe_manager_url( self, value: Option<String>, ) -> DeploymentConfigBuilder<SetManagerUrl<S>>
where S::ManagerUrl: IsUnset,

Optional (Some / Option setters). Manager base URL (e.g., “https://manager.alien.dev”).

The manager IS the container registry — its /v2/ endpoint serves as the OCI Distribution API. Controllers derive the proxy host from this to configure pull auth (RegistryCredentials, imagePullSecrets).

When None (e.g., alien dev), controllers use image URIs as-is.

pub fn deployment_token( self, value: String, ) -> DeploymentConfigBuilder<SetDeploymentToken<S>>
where S::DeploymentToken: IsUnset,

Optional (Some / Option setters). Deployment token for pull authentication with the manager’s registry.

Used by controllers to configure registry credentials so cloud platforms and K8s can pull images from the manager’s /v2/ endpoint.

pub fn maybe_deployment_token( self, value: Option<String>, ) -> DeploymentConfigBuilder<SetDeploymentToken<S>>
where S::DeploymentToken: IsUnset,

Optional (Some / Option setters). Deployment token for pull authentication with the manager’s registry.

Used by controllers to configure registry credentials so cloud platforms and K8s can pull images from the manager’s /v2/ endpoint.

pub fn native_image_host( self, value: String, ) -> DeploymentConfigBuilder<SetNativeImageHost<S>>
where S::NativeImageHost: IsUnset,

Optional (Some / Option setters). Native image registry host+prefix for platforms that require it.

Only Lambda (ECR) and Cloud Run (GAR) require native registry URIs. All other platforms pull through the manager’s proxy.

Derived by the manager from the artifact registry binding:

  • ECR: {account_id}.dkr.ecr.{region}.amazonaws.com/{repository_prefix}
  • GAR: {region}-docker.pkg.dev/{project_id}/{repository_name}
pub fn maybe_native_image_host( self, value: Option<String>, ) -> DeploymentConfigBuilder<SetNativeImageHost<S>>
where S::NativeImageHost: IsUnset,

Optional (Some / Option setters). Native image registry host+prefix for platforms that require it.

Only Lambda (ECR) and Cloud Run (GAR) require native registry URIs. All other platforms pull through the manager’s proxy.

Derived by the manager from the artifact registry binding:

  • ECR: {account_id}.dkr.ecr.{region}.amazonaws.com/{repository_prefix}
  • GAR: {region}-docker.pkg.dev/{project_id}/{repository_name}