pub struct Stack {
pub id: String,
pub resources: IndexMap<String, ResourceEntry>,
pub permissions: PermissionsConfig,
pub supported_platforms: Option<Vec<Platform>>,
pub inputs: Vec<StackInputDefinition>,
}Expand description
A bag of resources, unaware of any cloud.
Fields
id: StringUnique identifier for the stack
resources: IndexMap<String, ResourceEntry>Map of resource IDs to their configurations and lifecycle settings
permissions: PermissionsConfigCombined permissions configuration containing both profiles and management
supported_platforms: Option<Vec<Platform>>Which platforms this stack supports. When None, all platforms are supported.
inputs: Vec<StackInputDefinition>Input definitions required before setup or deployment can proceed.
Implementations
Sourceimpl Stack
impl Stack
Sourcepub fn new(id: String) -> StackBuilder
pub fn new(id: String) -> StackBuilder
Create an instance of Stack using the builder syntax
Sourceimpl Stack
impl Stack
Sourcepub fn resources(&self) -> impl Iterator<Item = (&String, &ResourceEntry)>
pub fn resources(&self) -> impl Iterator<Item = (&String, &ResourceEntry)>
Returns an iterator over the resources in the stack, including their lifecycle state.
Sourcepub fn resources_mut(
&mut self,
) -> impl Iterator<Item = (&String, &mut ResourceEntry)>
pub fn resources_mut( &mut self, ) -> impl Iterator<Item = (&String, &mut ResourceEntry)>
Returns a mutable iterator over the resources in the stack, including their lifecycle state.
pub fn id(&self) -> &str
Sourcepub fn permissions(&self) -> &PermissionsConfig
pub fn permissions(&self) -> &PermissionsConfig
Returns the permissions configuration for the stack.
Sourcepub fn permission_profiles(&self) -> &IndexMap<String, PermissionProfile>
pub fn permission_profiles(&self) -> &IndexMap<String, PermissionProfile>
Returns the permission profiles for the stack.
Sourcepub fn management(&self) -> &ManagementPermissions
pub fn management(&self) -> &ManagementPermissions
Returns the management permissions configuration for the stack.
Sourcepub fn supported_platforms(&self) -> Option<&[Platform]>
pub fn supported_platforms(&self) -> Option<&[Platform]>
Returns the supported platforms, or None if all platforms are supported.
Sourcepub fn inputs(&self) -> &[StackInputDefinition]
pub fn inputs(&self) -> &[StackInputDefinition]
Returns stack input definitions.
Sourcepub fn supports_platform(&self, platform: &Platform) -> bool
pub fn supports_platform(&self, platform: &Platform) -> bool
Returns true if the given platform is supported by this stack. When supported_platforms is None, all platforms are supported.